==> haskell-storablevector-0.2.13-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-BdqOXbnMeGE36a0Dm0lATX
key: storablevector-0.2.13-BdqOXbnMeGE36a0Dm0lATX
license: BSD-3-Clause
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
abi: 1c2be0b0a4f49dc7d3130d9d9ea7d42c
exposed: True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
import-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-BdqOXbnMeGE36a0Dm0lATX
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW base-4.12.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-5edbjI6eCGBo4Ew4MV2GP
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW transformers-0.5.6.2
    unsafe-0.0-t7t4lSr6WV4IGS6VALirJ
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-8ikBHu7EEL1JnPzELf5GsI
key: storablevector-0.2.13-8ikBHu7EEL1JnPzELf5GsI
license: BSD-3-Clause
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
abi: 7d669b18ac4bd4e91318219b8f29c3a0
exposed: True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
import-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-8ikBHu7EEL1JnPzELf5GsI
depends:
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD base-4.12.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-EAkjgjDTfioJKpDjlVBSLi
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW transformers-0.5.6.2
    unsafe-0.0-t7t4lSr6WV4IGS6VALirJ
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
